#include "back_light.h"

// Define Local VARIABLES
static pwm_t pwm;                // PWM driver context structure.
static pwm_config_t pwm_cfg;     // PWM driver configuration structure.
static digital_in_t input_pin1;
static digital_in_t input_pin2;

uint8_t button1_value;
uint8_t button2_value;
uint8_t duty = 0;


// USER CODE
void back_light_init(void) {

    // Initializes digital input driver context structure and individual GPIO pin as digital input.
    digital_in_init( &input_pin1, BUTTON1 );
    digital_in_init( &input_pin2, BUTTON2 );

    // Initializes PWM configuration structure to default values.
    pwm_configure_default( &pwm_cfg );

    // Set PWM pin.
    pwm_cfg.pin = BACKLIGHT_PWM_PIN;

    // Allocate resources for PWM module.
    if( PWM_ERROR == pwm_open( &pwm, &pwm_cfg )) {
        // Error handling.
//        return PWM_ERROR;
    }

    // Set PWM frequency and initialize PWM module on hardware level.
    pwm_set_freq( &pwm, PWM_FREQ_HZ );

    // Start PWM module.
    pwm_start( &pwm );
    pwm_set_duty( &pwm, .5 );
    duty = 50;
}

void back_light_update(void)  {
    
    button1_value = digital_in_read( &input_pin1 );
    button2_value = digital_in_read( &input_pin2 );

    if( 1 != button1_value ) {
        if( duty < 100 ) {
            duty = duty + 1;
            pwm_set_duty( &pwm, (float)duty / 100 );
            Delay_ms(5);
            } else {
                duty = 100; // Value greater than 100, set to 100
                pwm_set_duty( &pwm, (float)duty / 100 );
            }
        }

    if( 1 != button2_value ) {
        if( duty > 0 && duty <= 100 ) {
            duty = duty - 1;
            pwm_set_duty( &pwm, (float)duty / 100 );
            Delay_ms(5);
        } else {
            duty = 0; // Value equal to zero or greater than 100, set to 1
            pwm_set_duty( &pwm, (float)duty / 100 );
            }
    }
}

void back_light_set(uint8_t set_point)  {
    
    if( duty >= 0 && duty <= 100 ) {
        pwm_set_duty( &pwm, (float)set_point / 100 );
        duty = set_point; // save the new duty
        Delay_ms(5);
    } else {
        duty = 100; // bad value set duty to 100
        pwm_set_duty( &pwm, (float)set_point / 100 );
    }
}

