/**
 * @file main.c
 * @brief Main function for clk4_ILI9488 application.
 */

/**
 * Any initialization code needed for MCU to function properly.
 * Do not remove this line or clock might not be set correctly.
 */
//#define GCC // NOTE timer code only work MIKROE AI compiler at this time
              // Uncomment the above comment #define if using GCC or clang compiler
              // Turns off brightness control

#ifdef PREINIT_SUPPORTED
#include "preinit.h"
#endif

#ifdef MikroCCoreVersion
    #if MikroCCoreVersion >= 1
        #include "delays.h"
    #endif
#endif

// ------------------------------------------------------------------- INCLUDES

#include "log.h"
#include "lcd_ili9488.h"
#include "ili9488_image.h"
#include "L_test img.h"
#include "P_test img.h"
#include "ili9488_font.h"
#include "back_light.h"
#include "board.h"
#include "hal_ll_tim.h"

// ------------------------------------------------------------------ VARIABLES

static lcd_ili9488_t lcd_ili9488;
static log_t logger;
static digital_out_t out_pin;

#ifndef GCC
// Timer2 init
void InitTimer2()
{
//Timer2 Prescaler :27; Preload = 59999; Actual Interrupt Time = 10 ms

    RCC_APB1ENR.TIM2EN = 1;
    TIM2_CR1.CEN = 0;
    TIM2_PSC = 27;
    TIM2_ARR = 59999;
    interrupt_enable(IVT_INT_TIM2);
    TIM2_DIER.UIE = 1;
    TIM2_CR1.CEN = 1;
}

// this what we execute when the tic happens
void Timer2_interrupt() iv IVT_INT_TIM2
{
    TIM2_SR.UIF = 0;  // Clear the interrupt flag
    back_light_update(); // need to move this to some sort ticker so it gets checked regularly
    digital_out_toggle(&out_pin); // Toggle the LED on and off
}
#endif

void application_init(void)
{
    back_light_init(); //Initialize backlighting NOTE: until changed backlight 50%
    back_light_set(100); // set the backlight to 100%
    Delay_ms(10);

    /**
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX
     * are defined as HAL_PIN_NC, you will
     * need to define them manually for log to work.
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    log_cfg_t log_cfg; // Initialize the log printing when in debug mode
    LOG_MAP_USB_UART(log_cfg);
    log_init(&logger, &log_cfg);
    log_info(&logger, "-- logger Initialization Completed --");


    //  Display initialization.
    log_info(&logger, "-- Display Initialization Start --");
    lcd_ili9488_cfg_t cfg;
    lcd_ili9488_cfg_setup(&cfg);
    LCD_ILI9488_MAP_IO(cfg);
    lcd_ili9488_init(&lcd_ili9488, &cfg);
    lcd_ili9488_default_cfg(&lcd_ili9488);

    log_info(&logger, "-- Display Initialization Completed --");

    digital_out_init(&out_pin, PA10); // Define the LED bit

#ifndef GCC
    InitTimer2(); // Initialize and start the timer
#endif
}

void application_task(void)
{
    lcd_ili9488_fill_screen(&lcd_ili9488, BLACK); // clear the screen

    // Rectangle demo
    lcd_ili9488_rectangle(&lcd_ili9488, 0, 0, 96, 96, RED);
    Delay_ms(200);
    lcd_ili9488_rectangle(&lcd_ili9488, 5, 5, 91, 91, DEEP_RED);
    Delay_ms(200);
    lcd_ili9488_rectangle(&lcd_ili9488, 10, 10, 86, 86, GREEN);
    Delay_ms(200);
    lcd_ili9488_rectangle(&lcd_ili9488, 15, 15, 81, 81, YELLOW);
    Delay_ms(200);
    lcd_ili9488_rectangle(&lcd_ili9488, 20, 20, 76, 76, RED);
    Delay_ms(200);
    lcd_ili9488_rectangle(&lcd_ili9488, 25, 25, 71, 71, DEEP_RED);
    Delay_ms(200);

    // Line demo
    lcd_ili9488_line(&lcd_ili9488, 25, 25, 71, 25, GREEN);
    Delay_ms(200);
    lcd_ili9488_line(&lcd_ili9488, 25, 71, 71, 71, GREEN);
    Delay_ms(200);
    lcd_ili9488_line(&lcd_ili9488, 25, 25, 25, 71, GREEN);
    Delay_ms(200);
    lcd_ili9488_line(&lcd_ili9488, 71, 25, 71, 71, GREEN);

    // lets do a couple of diagonal lines
    lcd_ili9488_line(&lcd_ili9488, 105, 5, 185, 96, YELLOW);
    Delay_ms(200);
    lcd_ili9488_line(&lcd_ili9488, 185, 5, 105, 96, YELLOW);
    Delay_ms(200);

    // Text demo
    lcd_ili9488_set_font(&lcd_ili9488, guiFont_Tahoma_18_Regular, GREEN);
    lcd_ili9488_text(&lcd_ili9488, "This is the demo for ILI9488", 5, 105);
    lcd_ili9488_set_font(&lcd_ili9488, guiFont_Tahoma_16_Regular, RED);
    lcd_ili9488_text(&lcd_ili9488, "Tahoma 16 point", 5, 131);
    lcd_ili9488_set_font(&lcd_ili9488, guiFont_Tahoma_14_Regular, BLUE);
    lcd_ili9488_text(&lcd_ili9488, "Tahoma 14 point", 5, 154);
    lcd_ili9488_set_font(&lcd_ili9488, guiFont_Tahoma_10_Regular, WHITE);
    lcd_ili9488_text(&lcd_ili9488, "Tahoma 10 point", 5, 177);

    // Image demo 16 bit color (RRRRRGGGGGGBBBBB)
    lcd_ili9488_image(&lcd_ili9488, mikroe_with_slogan96x96, 196, 0, RGB16);

    // Circle demo
    lcd_ili9488_circle(&lcd_ili9488, 55, 265, 50, RED, 5);
    Delay_ms(200);
    lcd_ili9488_fill_circle(&lcd_ili9488, 170, 265, 50, RED);
    Delay_ms(200);
    lcd_ili9488_circle(&lcd_ili9488, 260, 240, 20, GREEN, 1);
    Delay_ms(200);
    lcd_ili9488_fill_circle(&lcd_ili9488, 260, 290, 20, GREEN);
    Delay_ms(3000);

    lcd_ili9488_fill_screen(&lcd_ili9488, BLACK); // clear the screen

    // Image demo 24 bit color image 3 bytes (RRRRRRRR, GGGGGGGG, BBBBBBBB)
    #ifdef LANDSCAPE
    lcd_ili9488_image(&lcd_ili9488, IMG_3671_L, 0, 0, RGB24); // this fills the width of the landscape screen
    #else
    lcd_ili9488_image(&lcd_ili9488, IMG_3671_P, 0, 0, RGB24); // this fills the width of the portrait screen
    #endif

    Delay_ms(3000);
    printf_me("loop complete\r\n");

}

// ------------------------------------------------------ APPLICATION FUNCTIONS

int main(void)
{
/* Do not remove this line or clock might not be set correctly. */
#ifdef PREINIT_SUPPORTED
    preinit();
#endif

    application_init();

    for (;;)
    {
        application_task();
    }
    return 0;
}
